@@ -1,10 +1,11 @@
 #' Plot of latent node cluster
 #'
-#' Plot latent node cluster
-#' 
+#' Plot latent node cluster using ggplot2.
+#' Uses tidyr for data reshaping and viridis for colorblind-friendly palettes.
+#'
 #' @param mcmcout NetworkChange output
 #' @param Y Input raw data
-#' @param point.cex node point size.  Default is 3. 
+#' @param point.cex node point size.  Default is 3.
 #' @param text.cex node label size.  Default is 3.
 #' @param segment.size segment size.  Default is 0.1.
 #' @param n.cluster number of cluster. Default is 3.
@@ -13,13 +14,14 @@
 #'
 #' @references   Jong Hee Park and Yunkyun Sohn. 2020. "Detecting Structural Change
 #' in Longitudinal Network Data." \emph{Bayesian Analysis}. Vol.15, No.1, pp.133-157.
-#' 
+#'
 #' @return A plot object
 #'
-#' @importFrom reshape melt
+#' @importFrom tidyr pivot_longer
 #' @importFrom ggrepel geom_text_repel
+#' @importFrom ggplot2 scale_color_viridis_d alpha
 #' @importFrom rlang .data
-#' 
+#'
 #' @export
 #'
 #' @examples
@@ -42,12 +44,12 @@ drawPostAnalysis <- function(mcmcout, Y, point.cex=3,  text.cex=3,
   U <- attr(mcmcout, "U")
   V <- attr(mcmcout, "V")
   R <- attr(mcmcout, "R")
-  K <- dim(Y);
+  K <- dim(Y)
   T <- K[3]
   if(is.null(dimnames(Y))){
-     dimnames(Y)[[1]]<-c(1:dim(Y)[1])
-     dimnames(Y)[[2]]<-c(1:dim(Y)[2])
-     dimnames(Y)[[3]]<-c(1:dim(Y)[3])
+     dimnames(Y)[[1]] <- as.character(1:dim(Y)[1])
+     dimnames(Y)[[2]] <- as.character(1:dim(Y)[2])
+     dimnames(Y)[[3]] <- as.character(1:dim(Y)[3])
   }
   median.s <- ceiling(apply(attr(mcmcout, "Smat"), 2, median))
   y <- ts(1:T, start=start, frequency=frequency)
@@ -59,7 +61,7 @@ drawPostAnalysis <- function(mcmcout, Y, point.cex=3,  text.cex=3,
     n.cluster <- rep(3, ns)
   }
   ## regime specific country names
-  names <- as.list(rep(NA, ns))
+  names <- vector("list", ns)
   for(t in 1:ns){
     names[[t]] <- dimnames(Y)[[1]]
   }
@@ -71,9 +73,10 @@ drawPostAnalysis <- function(mcmcout, Y, point.cex=3,  text.cex=3,
 
   net <- array(NA, dim=c(N, N, ns))
   D <- t(sapply(1:time, function(t){V[t, order(V[t,], decreasing=TRUE)]}))
-  Dmat <- as.data.frame(cbind(Year, D))
-  colnames(Dmat) <- c("Year", "1st", "2nd")
-  D.long <- reshape::melt(Dmat, id.vars="Year")
+  Dmat <- data.frame(Year = Year, `1st` = D[,1], `2nd` = D[,2], check.names = FALSE)
+  ## Use tidyr::pivot_longer instead of reshape::melt
+  D.long <- tidyr::pivot_longer(Dmat, cols = c("1st", "2nd"),
+                                names_to = "variable", values_to = "value")
   D.regime <- matrix(NA, ns, R)
 
   for(t in 1:ns){
@@ -82,30 +85,31 @@ drawPostAnalysis <- function(mcmcout, Y, point.cex=3,  text.cex=3,
   }
 
   ## multiplot object
-  U.list <- .df.list <- title.list <- time.period <- as.list(rep(NA, ns))
-  p.list <- as.list(rep(NA, ns))
+  U.list <- .df.list <- title.list <- time.period <- vector("list", ns)
+  p.list <- vector("list", ns)
   median.s <- ceiling(apply(attr(mcmcout, "Smat"), 2, median))
   First <- Second <- Size <- Names <- Cluster <- NULL
   for(i in 1:ns){
     time.period[[i]] <- paste0(range(Year[median.s == i])[1], "-", range(Year[median.s == i])[2])
     U.list[[i]] <- U[[i]]
     cls <- kmeans(U.list[[i]], n.cluster[i], nstart = 20)
-    ## U.list[[i]] <- matrix(apply(out[[i]], 2, mean), dim(Y)[1], R)
     .df.list[[i]] <- data.frame(First = U.list[[i]][,1], Second = U.list[[i]][,2],
                                Size = sqrt((U.list[[i]][,1])^2 + (U.list[[i]][,2])^2),
                                Names = names[[i]],
                                Cluster = factor(cls$cluster))
     title.list[[i]] <- paste0("Regime ", i, " (", time.period[[i]], ")")
     p.list[[i]] <- ggplot(.df.list[[i]], aes(x=First, y = Second, label=Names, color=Cluster)) +
-      geom_point(aes(colour = Cluster, alpha=1/2), size = point.cex, show.legend=F) +
+      geom_point(aes(colour = Cluster), alpha = 0.5, size = point.cex, show.legend = FALSE) +
+      scale_color_viridis_d(option = "D") +
       scale_size_continuous(guide = "none") +
       ggtitle(title.list[[i]]) +
-      labs(x = paste("v[1] = ", round(D.regime[i, 1], 2))) +
-      labs(y = paste("v[2] = ", round(D.regime[i, 2], 2)))  +
-      ggrepel::geom_text_repel(size = text.cex, segment.size = segment.size, segment.color = alpha("navy", 1/6),
-                      colour = "navy", aes(label = Names)) +
-      theme(axis.title=element_text(size=8), plot.title = element_text(lineheight=.8, face="bold", hjust = 0.5))
-
+      labs(x = paste("v[1] = ", round(D.regime[i, 1], 2)),
+           y = paste("v[2] = ", round(D.regime[i, 2], 2))) +
+      ggrepel::geom_text_repel(size = text.cex, segment.size = segment.size,
+                               segment.color = alpha("navy", 1/6),
+                               colour = "navy", aes(label = Names)) +
+      theme_networkchange() +
+      theme(axis.title = element_text(size = 8))
   }
   attr(p.list, "title.list") <- title.list
   attr(p.list, "D.long") <- D.long
